﻿using ProjectAtelier.Entities;
using ProjectAtelier.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectAtelier.Forms
{
    public partial class FormClient : Form
    {
        private readonly IClientRepository _clientRepository;
        private int? _clientId;

        public int Id
        {
            set
            {
                try
                {
                    var client = _clientRepository.ReadClientById(value);
                    if (client == null)
                    {
                        throw new InvalidDataException(nameof(client));
                    }
                    textBoxName.Text = client.Name;
                    textBoxPhone.Text = client.Phone;
                    SetCheckedListBoxGender(client.Gender); // Устанавливаем выбранные элементы
                    _clientId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }

        public FormClient(IClientRepository clientRepository)
        {
            InitializeComponent();
            _clientRepository = clientRepository ?? throw new ArgumentNullException(nameof(clientRepository));

            // Инициализация CheckedListBox с элементами перечисления Gender
            checkedListBoxGender.Items.AddRange(Enum.GetValues(typeof(Gender)).Cast<object>().ToArray());
        }

        private void ButtonAdd_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxName.Text) || string.IsNullOrWhiteSpace(textBoxPhone.Text))
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_clientId.HasValue)
                {
                    _clientRepository.UpdateClient(CreateClient(_clientId.Value));
                }
                else
                {
                    _clientRepository.CreateClient(CreateClient(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click(object sender, EventArgs e) => Close();

        private Client CreateClient(int id)
        {
            // Получаем выбранные значения из CheckedListBox
            Gender gender = Gender.None;
            foreach (var item in checkedListBoxGender.CheckedItems)
            {
                gender |= (Gender)item;
            }

            return Client.CreateEntity(id, textBoxName.Text, textBoxPhone.Text, gender);
        }

        private void SetCheckedListBoxGender(Gender gender)
        {
            checkedListBoxGender.ClearSelected();
            foreach (var item in checkedListBoxGender.Items)
            {
                if (gender.HasFlag((Gender)item))
                {
                    checkedListBoxGender.SetItemChecked(checkedListBoxGender.Items.IndexOf(item), true);
                }
            }
        }
    }
}