﻿using ProjectAtelier.Entities;
using ProjectAtelier.Repositories;
using ProjectAtelier.REPOSITORY;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectAtelier.Forms
{
    public partial class FormMaterialReplenishment : Form
    {
        private readonly IMaterialReplenishmentRepository _materialReplenishmentRepository;
        private readonly IMaterialRepository _materialRepository; // Добавляем репозиторий для материалов
        private int? _materialReplenishmentId;

        public int Id
        {
            set
            {
                try
                {
                    var materialReplenishment = _materialReplenishmentRepository.ReadMaterialSpentById(value);
                    if (materialReplenishment == null)
                    {
                        throw new InvalidDataException(nameof(materialReplenishment));
                    }
                    
                    numericUpDownCount.Value = materialReplenishment.Count;
                    comboBoxMaterial.SelectedValue = materialReplenishment.IDMaterial; // Устанавливаем выбранный материал
                    dateTimePicker.Value = materialReplenishment.DataTime; // Устанавливаем выбранную дату и время
                    _materialReplenishmentId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }

        public FormMaterialReplenishment(IMaterialReplenishmentRepository materialReplenishmentRepository, IMaterialRepository materialRepository)
        {
            InitializeComponent();
            _materialReplenishmentRepository = materialReplenishmentRepository ?? throw new ArgumentNullException(nameof(materialReplenishmentRepository));
            _materialRepository = materialRepository ?? throw new ArgumentNullException(nameof(materialRepository));

            // Заполняем ComboBox для выбора материала
            comboBoxMaterial.DataSource = _materialRepository.ReadMaterials();
            comboBoxMaterial.DisplayMember = "Name";
            comboBoxMaterial.ValueMember = "Id";
        }

        private MaterialReplenishment CreateMaterialReplenishment(int id)
        {
            int selectedMaterialId = (int)comboBoxMaterial.SelectedValue;
            DateTime selectedDateTime = dateTimePicker.Value;
            return MaterialReplenishment.CreateOperation(id,  Convert.ToInt32(numericUpDownCount.Value), selectedDateTime, selectedMaterialId);
        }

        private void ButtonAdd_Click_1(object sender, EventArgs e)
        {
            try
            {
                if (comboBoxMaterial.SelectedIndex < 0)
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_materialReplenishmentId.HasValue)
                {
                    _materialReplenishmentRepository.UpdateMaterialSpent(CreateMaterialReplenishment(_materialReplenishmentId.Value));
                }
                else
                {
                    _materialReplenishmentRepository.CreateMaterialSpent(CreateMaterialReplenishment(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click_1(object sender, EventArgs e) => Close();
    }
}